Behavior class
Constructors
- Behavior({AdShortShow? adShortShow, AdShortClose? adShortClose, int? wrongDeemAdLess, int? wrongDeemAdMore, int? noInstall, int? adDailyShow})
- Behavior.fromJson(dynamic json)
Properties
- adDailyShow ↔ int?
-
getter/setter pair
- adShortClose ↔ AdShortClose?
-
getter/setter pair
- adShortShow ↔ AdShortShow?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- noInstall ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wrongDeemAdLess ↔ int?
-
getter/setter pair
- wrongDeemAdMore ↔ int?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited