MethodChannelFlutterRiskControlPlugins class

An implementation of FlutterRiskControlPluginsPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkDownloadFromStore() Future<bool>
override
checkHasRoot() Future<bool>
override
checkHasSim() Future<bool>
override
checkIsDeveloper() Future<bool>
override
checkIsSimulator() Future<bool>
override
checkOpenVpn() Future<bool>
override
getNumberUnitID({String channel = "", String message = ""}) Future<String>
override
initNumberUnit(String apiKey) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited