RiskControlConfigUtils class

Constructors

RiskControlConfigUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkBehaviorOpen() bool
checkDeviceOpen() bool
checkDeviceRiskControl(RiskControlTagEnum tag) bool
checkNumberOpen() bool
getAdShortClose() AdShortClose?
getAdShortShow() AdShortShow?
getWrongDeemAdLess() int
getWrongDeemAdMore() int
initConfigBean(String s, RiskControlCallback? riskControlCallback) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
playAdTimeSoShort() bool
toString() String
A string representation of this object.
inherited
twoRewardAdTimeSoShort() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance RiskControlConfigUtils
no setter