RiskControlCallback class
Constructors
-
RiskControlCallback({required dynamic setVideoAdMaxShowNum(int count), required dynamic uploadSessionCustom(Map<
String, int> map), required dynamic uploadRiskChance(RiskControlTagEnum tag)})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setVideoAdMaxShowNum ↔ dynamic Function(int count)
-
getter/setter pair
- uploadRiskChance ↔ dynamic Function(RiskControlTagEnum tag)
-
getter/setter pair
-
uploadSessionCustom
↔ dynamic Function(Map<
String, int> map) -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited